@@ -57,13 +57,13 @@ init_entry (GnmDialogSOList *state, GtkBuilder *gui, int col, int row,
 {
 	GnmExprEntry *gee = gnm_expr_entry_new (state->wbcg, TRUE);
 	GtkWidget *w = GTK_WIDGET (gee);
-	GtkTable *table = GTK_TABLE (gtk_builder_get_object (gui, "table"));
+	GtkGrid *grid = GTK_GRID (gtk_builder_get_object (gui, "main-grid"));
 	Sheet *sheet = sheet_object_get_sheet (state->so);
 	GnmParsePos pp;
 
 	g_return_val_if_fail (w != NULL, NULL);
 
-	gtk_table_attach (table, w, col, col + 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+	gtk_grid_attach (grid, w, col, row, 1, 1);
 	gnm_expr_entry_set_flags (gee, GNM_EE_FORCE_ABS_REF |
 				  GNM_EE_SHEET_OPTIONAL |
 				  GNM_EE_SINGLE_RANGE, GNM_EE_MASK);
@@ -86,9 +86,9 @@ cb_so_list_response (GtkWidget *dialog, gint response_id, GnmDialogSOList *state
 
 		parse_pos_init (&pp, sheet->workbook, sheet, 0, 0);
 		output = gnm_expr_entry_parse (state->link_entry,
-					       &pp, NULL, FALSE, GNM_EE_FORCE_ABS_REF);
+					       &pp, NULL, FALSE, GNM_EXPR_PARSE_FORCE_ABSOLUTE_REFERENCES);
 		content = gnm_expr_entry_parse (state->content_entry,
-						&pp, NULL, FALSE, GNM_EE_FORCE_ABS_REF);
+						&pp, NULL, FALSE, GNM_EXPR_PARSE_FORCE_ABSOLUTE_REFERENCES);
 		cmd_so_set_links (WORKBOOK_CONTROL (state->wbcg), state->so, output, content,
 				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 								(state->as_index_radio)));
@@ -100,7 +100,6 @@ cb_so_list_response (GtkWidget *dialog, gint response_id, GnmDialogSOList *state
 static gboolean
 so_list_init (GnmDialogSOList *state, WBCGtk *wbcg, SheetObject *so)
 {
-	GtkTable *table;
 	GnmExprTop const *texpr;
 	GtkBuilder *gui;
 
@@ -111,7 +110,10 @@ so_list_init (GnmDialogSOList *state, WBCGtk *wbcg, SheetObject *so)
 	state->wbcg   = wbcg;
 	state->so     = so;
 	state->dialog = go_gtk_builder_get_widget (gui, "SOList");
-	table = GTK_TABLE (go_gtk_builder_get_widget (gui, "table"));
+
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog),
+					   state->wbcg,
+					   GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED);
 
 	texpr = sheet_widget_list_base_get_content_link (so);
 	state->content_entry = init_entry (state, gui, 1, 4, texpr);
