@@ -696,6 +696,31 @@ gnm_object_get_bool (gpointer o, const char *name)
 	return b;
 }
 
+gboolean
+gnm_object_has_readable_prop (gconstpointer obj, const char *property,
+			      GType typ, gpointer pres)
+{
+	GObjectClass *klass;
+	GParamSpec *spec;
+
+	if (!obj)
+		return FALSE;
+
+	klass =  G_OBJECT_GET_CLASS (G_OBJECT (obj));
+	spec = g_object_class_find_property (klass, property);
+	if (!spec ||
+	    !(G_PARAM_READABLE & spec->flags) ||
+	    (typ != G_TYPE_NONE && spec->value_type != typ))
+		return FALSE;
+
+	if (pres)
+		g_object_get (G_OBJECT (obj), property, pres, NULL);
+	return TRUE;
+}
+
+
+
+
 gint
 gnm_float_equal (gnm_float const *a, const gnm_float *b)
 {
@@ -717,3 +742,65 @@ gnm_float_hash (gnm_float const *d)
 
 /* ------------------------------------------------------------------------- */
 
+struct cb_compare {
+	GnmHashTableOrder order;
+	gpointer user;
+};
+
+static gint
+cb_compare (gconstpointer a_, gconstpointer b_, gpointer user_data)
+{
+	struct cb_compare *user = user_data;
+	gpointer *a = (gpointer )a_;
+	gpointer *b = (gpointer )b_;
+
+	return user->order (a[0], a[1], b[0], b[1], user->user);
+}
+
+
+/**
+ * gnm_hash_table_foreach_ordered:
+ * @h: Hash table
+ * @callback: (scope async): #GHFunc
+ * @order: (scope async): Ordering function
+ * @user: user data for callback and order
+ *
+ * Like g_hash_table_foreach, but with an ordering imposed.
+ **/
+void
+gnm_hash_table_foreach_ordered (GHashTable *h,
+				GHFunc callback,
+				GnmHashTableOrder order,
+				gpointer user)
+{
+	unsigned ui;
+	GPtrArray *data;
+	struct cb_compare u;
+	GHashTableIter hiter;
+	gpointer key, value;
+
+	/* Gather all key-value pairs */
+	data = g_ptr_array_new ();
+	g_hash_table_iter_init (&hiter, h);
+	while (g_hash_table_iter_next (&hiter, &key, &value)) {
+		g_ptr_array_add (data, key);
+		g_ptr_array_add (data, value);
+	}
+
+	/* Sort according to given ordering */
+	u.order = order;
+	u.user = user;
+	g_qsort_with_data (data->pdata,
+			   data->len / 2, 2 * sizeof (gpointer),
+			   cb_compare,
+			   &u);
+
+	/* Call user callback with all pairs */
+	for (ui = 0; ui < data->len; ui += 2)
+		callback (g_ptr_array_index (data, ui),
+			  g_ptr_array_index (data, ui + 1),
+			  user);
+
+	/* Clean up */
+	g_ptr_array_free (data, TRUE);
+}
