@@ -96,25 +96,25 @@ analysis_tool_anova_two_factor_no_rep_engine_run (data_analysis_output_t *dao,
 	GnmFunc *fd_fdist;
 	GnmFunc *fd_finv;
 
-	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
 	gnm_func_ref (fd_index);
-	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
 	gnm_func_ref (fd_offset);
-	fd_count = gnm_func_lookup_or_add_placeholder ("COUNT", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_count = gnm_func_lookup_or_add_placeholder ("COUNT");
 	gnm_func_ref (fd_count);
-	fd_sum = gnm_func_lookup_or_add_placeholder ("SUM", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_sum = gnm_func_lookup_or_add_placeholder ("SUM");
 	gnm_func_ref (fd_sum);
-	fd_sumsq = gnm_func_lookup_or_add_placeholder ("SUMSQ", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_sumsq = gnm_func_lookup_or_add_placeholder ("SUMSQ");
 	gnm_func_ref (fd_sumsq);
-	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE");
 	gnm_func_ref (fd_average);
-	fd_var = gnm_func_lookup_or_add_placeholder ("VAR", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_var = gnm_func_lookup_or_add_placeholder ("VAR");
 	gnm_func_ref (fd_var);
-	fd_if = gnm_func_lookup_or_add_placeholder ("IF", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_if = gnm_func_lookup_or_add_placeholder ("IF");
 	gnm_func_ref (fd_if);
-	fd_fdist = gnm_func_lookup_or_add_placeholder ("FDIST", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_fdist = gnm_func_lookup_or_add_placeholder ("FDIST");
 	gnm_func_ref (fd_fdist);
-	fd_finv = gnm_func_lookup_or_add_placeholder ("FINV", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_finv = gnm_func_lookup_or_add_placeholder ("FINV");
 	gnm_func_ref (fd_finv);
 
 	dao_set_merge (dao, 0, 0, 4, 0);
@@ -244,9 +244,9 @@ analysis_tool_anova_two_factor_no_rep_engine_run (data_analysis_output_t *dao,
 					"/Total"));
 	dao_set_italic (dao, 1, r, 6, r);
 	dao_set_border (dao, 0, r, 6, r, MSTYLE_BORDER_BOTTOM, GNM_STYLE_BORDER_THIN,
-			style_color_black (), GNM_STYLE_BORDER_HORIZ);
+			style_color_black (), GNM_STYLE_BORDER_HORIZONTAL);
 	dao_set_border (dao, 0, r+3, 6, r+3, MSTYLE_BORDER_BOTTOM, GNM_STYLE_BORDER_THIN,
-			style_color_black (), GNM_STYLE_BORDER_HORIZ);
+			style_color_black (), GNM_STYLE_BORDER_HORIZONTAL);
 	set_cell_text_row (dao, 1, r, _("/SS"
 					"/df"
 					"/MS"
@@ -434,25 +434,25 @@ analysis_tool_anova_two_factor_engine_run (data_analysis_output_t *dao,
 	GnmFunc *fd_fdist;
 	GnmFunc *fd_finv;
 
-	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
 	gnm_func_ref (fd_index);
-	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
 	gnm_func_ref (fd_offset);
-	fd_count = gnm_func_lookup_or_add_placeholder ("COUNT", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_count = gnm_func_lookup_or_add_placeholder ("COUNT");
 	gnm_func_ref (fd_count);
-	fd_sum = gnm_func_lookup_or_add_placeholder ("SUM", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_sum = gnm_func_lookup_or_add_placeholder ("SUM");
 	gnm_func_ref (fd_sum);
-	fd_sumsq = gnm_func_lookup_or_add_placeholder ("SUMSQ", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_sumsq = gnm_func_lookup_or_add_placeholder ("SUMSQ");
 	gnm_func_ref (fd_sumsq);
-	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE");
 	gnm_func_ref (fd_average);
-	fd_var = gnm_func_lookup_or_add_placeholder ("VAR", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_var = gnm_func_lookup_or_add_placeholder ("VAR");
 	gnm_func_ref (fd_var);
-	fd_if = gnm_func_lookup_or_add_placeholder ("IF", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_if = gnm_func_lookup_or_add_placeholder ("IF");
 	gnm_func_ref (fd_if);
-	fd_fdist = gnm_func_lookup_or_add_placeholder ("FDIST", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_fdist = gnm_func_lookup_or_add_placeholder ("FDIST");
 	gnm_func_ref (fd_fdist);
-	fd_finv = gnm_func_lookup_or_add_placeholder ("FINV", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
+	fd_finv = gnm_func_lookup_or_add_placeholder ("FINV");
 	gnm_func_ref (fd_finv);
 
 	dao_set_merge (dao, 0, 0, 4, 0);
@@ -603,9 +603,9 @@ analysis_tool_anova_two_factor_engine_run (data_analysis_output_t *dao,
 					"/Total"));
 	dao_set_italic (dao, 1, r, 6, r);
 	dao_set_border (dao, 0, r, 6, r, MSTYLE_BORDER_BOTTOM, GNM_STYLE_BORDER_THIN,
-			style_color_black (), GNM_STYLE_BORDER_HORIZ);
+			style_color_black (), GNM_STYLE_BORDER_HORIZONTAL);
 	dao_set_border (dao, 0, r+4, 6, r+4, MSTYLE_BORDER_BOTTOM, GNM_STYLE_BORDER_THIN,
-			style_color_black (), GNM_STYLE_BORDER_HORIZ);
+			style_color_black (), GNM_STYLE_BORDER_HORIZONTAL);
 	set_cell_text_row (dao, 1, r, _("/SS"
 					"/df"
 					"/MS"
